PteMapper

Struct PteMapper 

pub struct PteMapper<'a, PTE, Mapper, Error>
where PTE: FromPrimitive + PrimInt + Unsigned, Mapper: PageTableMapper<PTE, Error>,
{ pub mapper: &'a mut Mapper, pub format: &'a PageFormat<'a, PTE>, pub mask: PTE, pub error: PhantomData<Error>, }
The PteMapper struct is an implementation of a crate::walker::PageWalkerMut used to map a physical address range and allocate the underlying page tables for a given virtual address range. This is used by the AddressSpace::map_range method.

Fields

mapper: &'a mut Mapper

The page table mapper.

format: &'a PageFormat<'a, PTE>

The page format.

mask: PTE

The mask to set for pages.

error: PhantomData<Error>

A marker for Error.