pub struct PteProtector<'a, PTE, Mapper, Error>{
pub mapper: &'a mut Mapper,
pub mask: (PTE, PTE),
pub format: &'a PageFormat<'a, PTE>,
pub error: PhantomData<Error>,
}Expand description
The PteProtector struct is an implementation of a crate::walker::PageWalkerMut used to
change the protection flags of a given virtual address range. This function is used by the
AddressSpace::protect_range method.
Fields
mapper: &'a mut MapperThe page table mapper.
mask: (PTE, PTE)The protection flags that should be set. The first mask is the mask of bits that should be cleared. The second mask is the mask of bits that should be set.
format: &'a PageFormat<'a, PTE>The page format.
error: PhantomData<Error>A marker for Error.